@@ -3,7 +3,7 @@
 # @Date:   2020-03-08 14:34:45
 # @E-mail: maoyongfan@163.com
 # @Last Modified by:   yongfanmao
-# @Last Modified time: 2020-09-16 17:11:23
+# @Last Modified time: 2020-09-16 19:41:55
 
 __version__ = "1.0"
 
@@ -68,6 +68,8 @@ class Request(object):
 							values = json.dumps(values)
 							data_struct['request'][key] = values
 					data_struct['request'] = json.dumps(data_struct['request'])
+				logger.info(data_struct)
+				print(data_struct)
 				rep = session.request(url=url, method=method, json=data_struct,headers=kwargs.get('headers',{}))
 				return rep.status_code,soa_loads(rep.text)
 			# 非加密http请求
